(function() {
    "use strict";

    /* globals angular */

    const yaml = require('js-yaml');
    const fs = require('fs');
    const path = require('path');
    const globule = require('globule');
    const moment = require('moment');

    let config;
    let configDir = 'rmconnect';
    let configPath = path.join(process.env.HOME || process.env.USERPROFILE, '/'+configDir+'/config.yml');
    let logsPath = path.join(process.env.HOME || process.env.USERPROFILE, '/'+configDir+'/logs/');

    try {
        config = yaml.safeLoad(fs.readFileSync(configPath, 'utf8'));
    } catch (e) {
        console.log(e);
    }

    let files = {};
    let logs = {};
    let logfiles = {};

    for (let key in config){
        console.log(key);
        files[key] = config[key];
        var cleanKey = config[key].currentKeyClean = key.replace(/(\W|\s)/g, '_');
        try {
            logfiles[cleanKey] = globule.find(logsPath + "/" + cleanKey + "/*.log");

            logfiles[cleanKey].reverse()
            logfiles[cleanKey].slice(0,30);
            
            let today = new moment();
            today = today.format('YYYY-MM-DD')
            let todaysLog  = globule.find(logsPath + "/" + cleanKey + "/" + today + ".log");
            
            if (typeof todaysLog[0] != 'undefined') {
                logs[cleanKey] = fs.readFileSync(todaysLog[0], 'utf-8').split('\n');
            }
        } catch (e) {
            logfiles[cleanKey] = e;
            logs[cleanKey] = [];
        }
    }
    
    var app = angular
                .module('rmApp', ['ngMaterial'])
                .constant('files', files)
                .constant('logs', logs)
                .constant('logfiles', logfiles);

    app.config(['$mdThemingProvider', function($mdThemingProvider) {
        $mdThemingProvider.definePalette('rmPrimaryPallet', {
            '50': 'fff000', //ffebee
            '100': 'e7f2d9', //ffcdd2
            '200': 'ef9a9a',
            '300': 'e57373',
            '400': 'ef5350',
            '500': '86be40', //f44336
            '600': '#f062a4', //e53935  //508e40
            '700': 'd32f2f',
            '800': 'c62828',
            '900': 'b71c1c', //f4000c
            'A100': 'ff8a80',
            'A200': '508e40',
            'A400': 'ff1744',
            'A700': 'd50000',
            'contrastDefaultColor': 'light',    // whether, by default, text (contrast)
                                                // on this palette should be dark or light
            'contrastDarkColors': ['50', '100', //hues which contrast should be 'dark' by default
                '200', '300', '400', 'A100'],
            'contrastLightColors': undefined    // could also specify this if default was 'dark'
        });

        $mdThemingProvider.theme('default').primaryPalette('rmPrimaryPallet').accentPalette('rmPrimaryPallet', {
            'default': 'A200'});
    }])
}());
